Method: Concurrent::Map#each_pair
- Defined in:
- lib/concurrent-ruby/concurrent/map.rb
#each_pair {|key, value| ... } ⇒ self Also known as: each
Note:
Atomic methods taking a block do not allow the self instance to be used within the block. Doing so will cause a deadlock.
Iterates over each key value pair. This method is atomic.
270 271 272 273 |
# File 'lib/concurrent-ruby/concurrent/map.rb', line 270 def each_pair return enum_for :each_pair unless block_given? super end |